=== modified file 'breezy/builtins.py'
--- breezy/builtins.py	2019-06-15 12:04:34 +0000
+++ breezy/builtins.py	2019-06-18 11:21:15 +0000
@@ -6260,9 +6260,8 @@
         from . import switch
         tree_location = directory
         revision = _get_one_revision('switch', revision)
-        possible_transports = []
-        control_dir = controldir.ControlDir.open_containing(tree_location,
-                                                            possible_transports=possible_transports)[0]
+        control_dir = controldir.ControlDir.open_containing(tree_location)[0]
+        possible_transports = [control_dir.root_transport]
         if to_location is None:
             if revision is None:
                 raise errors.BzrCommandError(gettext('You must supply either a'
@@ -6275,6 +6274,8 @@
         except errors.NotBranchError:
             branch = None
             had_explicit_nick = False
+        else:
+            possible_transports.append(branch.user_transport)
         if create_branch:
             if branch is None:
                 raise errors.BzrCommandError(
@@ -6291,17 +6292,19 @@
                 source_branch=branch).open_branch()
         else:
             try:
-                to_branch = Branch.open(to_location,
-                                        possible_transports=possible_transports)
+                to_branch = Branch.open(
+                    to_location, possible_transports=possible_transports)
             except errors.NotBranchError:
                 to_branch = open_sibling_branch(
                     control_dir, to_location,
                     possible_transports=possible_transports)
             if revision is not None:
                 revision = revision.as_revision_id(to_branch)
+        possible_transports.append(to_branch.user_transport)
         try:
             switch.switch(control_dir, to_branch, force, revision_id=revision,
-                          store_uncommitted=store)
+                          store_uncommitted=store,
+                          possible_transports=possible_transports)
         except controldir.BranchReferenceLoop:
             raise errors.BzrCommandError(
                 gettext('switching would create a branch reference loop. '

=== modified file 'breezy/bzr/bzrdir.py'
--- breezy/bzr/bzrdir.py	2019-06-06 22:22:47 +0000
+++ breezy/bzr/bzrdir.py	2019-06-18 11:21:15 +0000
@@ -448,8 +448,11 @@
 
         # Create/update the result working tree
         if (create_tree_if_local and not result.has_workingtree()
-            and isinstance(target_transport, local.LocalTransport)
-                and (result_repo is None or result_repo.make_working_trees())):
+                and isinstance(target_transport, local.LocalTransport)
+                and (result_repo is None or result_repo.make_working_trees())
+                and result.open_branch(
+                    name="",
+                    possible_transports=possible_transports).name == result_branch.name):
             wt = result.create_workingtree(
                 accelerator_tree=accelerator_tree, hardlink=hardlink,
                 from_branch=result_branch)
@@ -1075,6 +1078,11 @@
             name = self._get_selected_branch()
         format = self.find_branch_format(name=name)
         format.check_support_status(unsupported)
+        if possible_transports is None:
+            possible_transports = []
+        else:
+            possible_transports = list(possible_transports)
+        possible_transports.append(self.root_transport)
         return format.open(self, name=name,
                            _found=True, ignore_fallbacks=ignore_fallbacks,
                            possible_transports=possible_transports)

=== modified file 'breezy/conflicts.py'
--- breezy/conflicts.py	2018-11-11 04:08:32 +0000
+++ breezy/conflicts.py	2019-06-16 16:46:13 +0000
@@ -20,6 +20,7 @@
 from __future__ import absolute_import
 
 import os
+import re
 
 from .lazy_import import lazy_import
 lazy_import(globals(), """
@@ -84,6 +85,8 @@
 
 
 resolve_action_registry.register(
+    'auto', 'auto', 'Detect whether conflict has been resolved by user.')
+resolve_action_registry.register(
     'done', 'done', 'Marks the conflict as resolved.')
 resolve_action_registry.register(
     'take-this', 'take_this',
@@ -137,38 +140,27 @@
         else:
             tree, file_list = workingtree.WorkingTree.open_containing_paths(
                 file_list, directory)
-            if file_list is None:
-                if action is None:
-                    # FIXME: There is a special case here related to the option
-                    # handling that could be clearer and easier to discover by
-                    # providing an --auto action (bug #344013 and #383396) and
-                    # make it mandatory instead of implicit and active only
-                    # when no file_list is provided -- vila 091229
+            if action is None:
+                if file_list is None:
                     action = 'auto'
-            else:
-                if action is None:
+                else:
                     action = 'done'
-        if action == 'auto':
-            if file_list is None:
-                un_resolved, resolved = tree.auto_resolve()
-                if len(un_resolved) > 0:
-                    trace.note(ngettext('%d conflict auto-resolved.',
-                                        '%d conflicts auto-resolved.', len(resolved)),
-                               len(resolved))
-                    trace.note(gettext('Remaining conflicts:'))
-                    for conflict in un_resolved:
-                        trace.note(text_type(conflict))
-                    return 1
-                else:
-                    trace.note(gettext('All conflicts resolved.'))
-                    return 0
+        before, after = resolve(tree, file_list, action=action)
+        # GZ 2012-07-27: Should unify UI below now that auto is less magical.
+        if action == 'auto' and file_list is None:
+            if after > 0:
+                trace.note(
+                    ngettext('%d conflict auto-resolved.',
+                             '%d conflicts auto-resolved.', before - after),
+                    before - after)
+                trace.note(gettext('Remaining conflicts:'))
+                for conflict in tree.conflicts():
+                    trace.note(text_type(conflict))
+                return 1
             else:
-                # FIXME: This can never occur but the block above needs some
-                # refactoring to transfer tree.auto_resolve() to
-                # conflict.auto(tree) --vila 091242
-                pass
+                trace.note(gettext('All conflicts resolved.'))
+                return 0
         else:
-            before, after = resolve(tree, file_list, action=action)
             trace.note(ngettext('{0} conflict resolved, {1} remaining',
                                 '{0} conflicts resolved, {1} remaining',
                                 before - after).format(before - after, after))
@@ -453,6 +445,9 @@
                 if e.errno != errno.ENOENT:
                     raise
 
+    def action_auto(self, tree):
+        raise NotImplementedError(self.action_auto)
+
     def action_done(self, tree):
         """Mark the conflict as solved once it has been handled."""
         # This method does nothing but simplifies the design of upper levels.
@@ -651,6 +646,8 @@
 
     rformat = '%(class)s(%(path)r, %(file_id)r)'
 
+    _conflict_re = re.compile(b'^(<{7}|={7}|>{7})')
+
     def associated_filenames(self):
         return [self.path + suffix for suffix in CONFLICT_SUFFIXES]
 
@@ -681,6 +678,22 @@
         tt.version_file(self.file_id, winner_tid)
         tt.apply()
 
+    def action_auto(self, tree):
+        # GZ 2012-07-27: Using NotImplementedError to signal that a conflict
+        #                can't be auto resolved does not seem ideal.
+        try:
+            kind = tree.kind(self.path)
+        except errors.NoSuchFile:
+            return
+        if kind != 'file':
+            raise NotImplementedError("Conflict is not a file")
+        conflict_markers_in_line = self._conflict_re.search
+        # GZ 2012-07-27: What if not tree.has_id(self.file_id) due to removal?
+        with tree.get_file(self.path) as f:
+            for line in f:
+                if conflict_markers_in_line(line):
+                    raise NotImplementedError("Conflict markers present")
+
     def action_take_this(self, tree):
         self._resolve_with_cleanups(tree, 'THIS')
 

=== modified file 'breezy/controldir.py'
--- breezy/controldir.py	2019-06-03 04:07:01 +0000
+++ breezy/controldir.py	2019-06-18 11:21:15 +0000
@@ -443,12 +443,12 @@
             try:
                 tree_to = self.open_workingtree()
             except errors.NotLocalUrl:
-                push_result.branch_push_result = source.push(br_to,
-                                                             overwrite, stop_revision=revision_id, lossy=lossy)
+                push_result.branch_push_result = source.push(
+                    br_to, overwrite, stop_revision=revision_id, lossy=lossy)
                 push_result.workingtree_updated = False
             except errors.NoWorkingTree:
-                push_result.branch_push_result = source.push(br_to,
-                                                             overwrite, stop_revision=revision_id, lossy=lossy)
+                push_result.branch_push_result = source.push(
+                    br_to, overwrite, stop_revision=revision_id, lossy=lossy)
                 push_result.workingtree_updated = None  # Not applicable
             else:
                 with tree_to.lock_write():

=== modified file 'breezy/errors.py'
--- breezy/errors.py	2019-06-16 01:03:51 +0000
+++ breezy/errors.py	2019-06-18 11:21:15 +0000
@@ -2145,10 +2145,11 @@
 class TagsNotSupported(BzrError):
 
     _fmt = ("Tags not supported by %(branch)s;"
-            " you may be able to use brz upgrade.")
+            " you may be able to use 'brz upgrade %(branch_url)s'.")
 
     def __init__(self, branch):
         self.branch = branch
+        self.branch_url = branch.user_url
 
 
 class TagAlreadyExists(BzrError):

=== modified file 'breezy/git/dir.py'
--- breezy/git/dir.py	2019-06-02 21:21:39 +0000
+++ breezy/git/dir.py	2019-06-18 11:21:15 +0000
@@ -182,6 +182,7 @@
         result_branch = source_branch.sprout(
             result, revision_id=revision_id, repository=result_repo)
         if (create_tree_if_local and
+            result.open_branch(name="").name == result_branch.name and
             isinstance(target_transport, LocalTransport) and
                 (result_repo is None or result_repo.make_working_trees())):
             result.create_workingtree(
@@ -302,6 +303,18 @@
             lossy=lossy)
         push_result.new_revid = push_result.branch_push_result.new_revid
         push_result.old_revid = push_result.branch_push_result.old_revid
+        try:
+            wt = self.open_workingtree()
+        except brz_errors.NoWorkingTree:
+            push_result.workingtree_updated = None
+        else:
+            if self.open_branch(name="").name == target.name:
+                wt._update_git_tree(
+                    old_revision=push_result.old_revid,
+                    new_revision=push_result.new_revid)
+                push_result.workingtree_updated = True
+            else:
+                push_result.workingtree_updated = False
         push_result.target_branch = target
         if source.get_push_location() is None or remember:
             source.set_push_location(push_result.target_branch.base)

=== modified file 'breezy/git/tests/test_blackbox.py'
--- breezy/git/tests/test_blackbox.py	2019-06-15 12:57:02 +0000
+++ breezy/git/tests/test_blackbox.py	2019-06-18 11:21:15 +0000
@@ -35,6 +35,7 @@
 from .. import (
     tests,
     )
+from ...tests.script import TestCaseWithTransportAndScript
 from ...tests.features import PluginLoadedFeature
 
 
@@ -212,7 +213,8 @@
         tree.add(['a'])
         output, error = self.run_bzr(['diff', '--format=git'], retcode=1)
         self.assertEqual(error, '')
-        # Some older versions of Dulwich (< 0.19.12) formatted diffs slightly differently.
+        # Some older versions of Dulwich (< 0.19.12) formatted diffs slightly
+        # differently.
         from dulwich import __version__ as dulwich_version
         if dulwich_version < (0, 19, 12):
             self.assertEqual(output,
@@ -422,6 +424,30 @@
                 self.assertEqual([], list(tree.iter_changes(basis_tree)))
 
 
+class SwitchScriptTests(TestCaseWithTransportAndScript):
+
+    def test_switch_preserves(self):
+        # See https://bugs.launchpad.net/brz/+bug/1820606
+        self.run_script("""
+$ brz init --git r
+Created a standalone tree (format: git)
+$ cd r
+$ echo original > file.txt
+$ brz add
+adding file.txt
+$ brz ci -q -m "Initial"
+$ echo "entered on master branch" > file.txt
+$ brz stat
+modified:
+  file.txt
+$ brz switch -b other
+2>Tree is up to date at revision 1.
+2>Switched to branch other
+$ cat file.txt
+entered on master branch
+""")
+
+
 class GrepTests(ExternalBase):
 
     def test_simple_grep(self):

=== modified file 'breezy/git/workingtree.py'
--- breezy/git/workingtree.py	2019-06-15 15:59:17 +0000
+++ breezy/git/workingtree.py	2019-06-18 11:21:15 +0000
@@ -1198,26 +1198,33 @@
                     (index, subpath) = self._lookup_index(entry.path)
                     index[subpath] = index_entry_from_stat(st, entry.sha, 0)
 
+    def _update_git_tree(self, old_revision, new_revision, change_reporter=None,
+                         show_base=False):
+        basis_tree = self.revision_tree(old_revision)
+        if new_revision != old_revision:
+            with basis_tree.lock_read():
+                new_basis_tree = self.branch.basis_tree()
+                merge.merge_inner(
+                    self.branch,
+                    new_basis_tree,
+                    basis_tree,
+                    this_tree=self,
+                    change_reporter=change_reporter,
+                    show_base=show_base)
+
     def pull(self, source, overwrite=False, stop_revision=None,
              change_reporter=None, possible_transports=None, local=False,
              show_base=False):
         with self.lock_write(), source.lock_read():
             old_revision = self.branch.last_revision()
-            basis_tree = self.basis_tree()
             count = self.branch.pull(source, overwrite, stop_revision,
                                      possible_transports=possible_transports,
                                      local=local)
-            new_revision = self.branch.last_revision()
-            if new_revision != old_revision:
-                with basis_tree.lock_read():
-                    new_basis_tree = self.branch.basis_tree()
-                    merge.merge_inner(
-                        self.branch,
-                        new_basis_tree,
-                        basis_tree,
-                        this_tree=self,
-                        change_reporter=change_reporter,
-                        show_base=show_base)
+            self._update_git_tree(
+                old_revision=old_revision,
+                new_revision=self.branch.last_revision(),
+                change_reporter=change_reporter,
+                show_base=show_base)
             return count
 
     def add_reference(self, sub_tree):

=== modified file 'breezy/switch.py'
--- breezy/switch.py	2018-11-16 23:28:26 +0000
+++ breezy/switch.py	2019-06-16 19:15:57 +0000
@@ -40,7 +40,7 @@
 
 
 def switch(control_dir, to_branch, force=False, quiet=False, revision_id=None,
-           store_uncommitted=False):
+           store_uncommitted=False, possible_transports=None):
     """Switch the branch associated with a checkout.
 
     :param control_dir: ControlDir of the checkout to change
@@ -148,15 +148,12 @@
                     'Unable to connect to current master branch %(target)s: '
                     '%(error)s To switch anyway, use --force.') %
                     e.__dict__)
-            b.lock_write()
-            try:
+            with b.lock_write():
                 b.set_bound_location(None)
                 b.pull(to_branch, overwrite=True,
                        possible_transports=possible_transports)
                 b.set_bound_location(to_branch.base)
                 b.set_parent(b.get_master_branch().get_parent())
-            finally:
-                b.unlock()
         else:
             # If this is a standalone tree and the new branch
             # is derived from this one, create a lightweight checkout.

=== modified file 'breezy/tests/blackbox/test_tags.py'
--- breezy/tests/blackbox/test_tags.py	2019-01-08 21:29:21 +0000
+++ breezy/tests/blackbox/test_tags.py	2019-06-15 18:57:07 +0000
@@ -443,6 +443,15 @@
                          'unknown              ?\n')
         self.assertEqual('', err)
 
+    def test_tag_unsupported(self):
+        tree = self.make_branch_and_tree('tree', format='dirstate')
+        out, err = self.run_bzr('tag -d tree blah', retcode=3)
+        self.assertEqual(out, '')
+        self.assertContainsRe(
+            err,
+            'brz: ERROR: Tags not supported by BzrBranch5\\(.*\\/tree\\/\\); '
+            'you may be able to use \'brz upgrade file:\\/\\/.*\\/tree\\/\'.')
+
 
 class TestSmartServerCat(TestCaseWithTransport):
 

=== modified file 'breezy/tests/per_controldir_colo/test_supported.py'
--- breezy/tests/per_controldir_colo/test_supported.py	2018-11-11 04:08:32 +0000
+++ breezy/tests/per_controldir_colo/test_supported.py	2019-04-13 21:37:04 +0000
@@ -114,10 +114,47 @@
                 'Control dir does not support creating new branches.')
         to_dir = from_tree.controldir.sprout(
             urlutils.join_segment_parameters(
-                other_branch.controldir.user_url, {"branch": "target"}))
+                other_branch.user_url, {"branch": "target"}))
         to_branch = to_dir.open_branch(name="target")
         self.assertEqual(revid, to_branch.last_revision())
 
+    def test_sprout_into_colocated_leaves_workingtree(self):
+        # a bzrdir can construct a branch and repository for itself.
+        if not self.bzrdir_format.is_supported():
+            # unsupported formats are not loopback testable
+            # because the default open will not open them and
+            # they may not be initializable.
+            raise tests.TestNotApplicable('Control dir format not supported')
+        if not self.bzrdir_format.supports_workingtrees:
+            raise tests.TestNotApplicable(
+                'Control dir format does not support working trees')
+        from_tree = self.make_branch_and_tree('from')
+        self.build_tree_contents([('from/foo', 'contents')])
+        from_tree.add(['foo'])
+        revid1 = from_tree.commit("rev1")
+        self.build_tree_contents([('from/foo', 'new contents')])
+        revid2 = from_tree.commit("rev2")
+        try:
+            other_branch = self.make_branch_and_tree("to")
+        except errors.UninitializableFormat:
+            raise tests.TestNotApplicable(
+                'Control dir does not support creating new branches.')
+
+        result = other_branch.controldir.push_branch(
+            from_tree.branch, revision_id=revid1)
+        self.assertTrue(result.workingtree_updated)
+        self.assertFileEqual('contents', 'to/foo')
+
+        from_tree.controldir.sprout(
+            urlutils.join_segment_parameters(
+                other_branch.user_url, {"branch": "target"}),
+            revision_id=revid2)
+        active_branch = other_branch.controldir.open_branch(name="")
+        self.assertEqual(revid1, active_branch.last_revision())
+        to_branch = other_branch.controldir.open_branch(name="target")
+        self.assertEqual(revid2, to_branch.last_revision())
+        self.assertFileEqual('contents', 'to/foo')
+
     def test_unicode(self):
         self.requireFeature(UnicodeFilenameFeature)
         if not self.bzrdir_format.is_supported():

=== modified file 'breezy/tests/test_workingtree.py'
--- breezy/tests/test_workingtree.py	2019-06-04 00:08:59 +0000
+++ breezy/tests/test_workingtree.py	2019-06-18 11:21:15 +0000
@@ -410,6 +410,12 @@
 
 class TestAutoResolve(TestCaseWithTransport):
 
+    def _auto_resolve(self, tree):
+        """Call auto_resolve on tree expecting deprecation"""
+        return self.applyDeprecated(
+            symbol_versioning.deprecated_in((3, 0, 1)),
+            tree.auto_resolve,)
+
     def test_auto_resolve(self):
         base = self.make_branch_and_tree('base')
         self.build_tree_contents([('base/hello', b'Hello')])
@@ -425,24 +431,24 @@
         this.merge_from_branch(other.branch)
         self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
                          this.conflicts())
-        this.auto_resolve()
-        self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
-                         this.conflicts())
-        self.build_tree_contents([('this/hello', b'<<<<<<<')])
-        this.auto_resolve()
-        self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
-                         this.conflicts())
-        self.build_tree_contents([('this/hello', b'=======')])
-        this.auto_resolve()
-        self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
-                         this.conflicts())
-        self.build_tree_contents([('this/hello', b'\n>>>>>>>')])
-        remaining, resolved = this.auto_resolve()
+        self._auto_resolve(this)
+        self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
+                         this.conflicts())
+        self.build_tree_contents([('this/hello', '<<<<<<<')])
+        self._auto_resolve(this)
+        self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
+                         this.conflicts())
+        self.build_tree_contents([('this/hello', '=======')])
+        self._auto_resolve(this)
+        self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
+                         this.conflicts())
+        self.build_tree_contents([('this/hello', '\n>>>>>>>')])
+        remaining, resolved = self._auto_resolve(this)
         self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
                          this.conflicts())
         self.assertEqual([], resolved)
         self.build_tree_contents([('this/hello', b'hELLO wORLD')])
-        remaining, resolved = this.auto_resolve()
+        remaining, resolved = self._auto_resolve(this)
         self.assertEqual([], this.conflicts())
         self.assertEqual([conflicts.TextConflict('hello', b'hello_id')],
                          resolved)
@@ -480,9 +486,23 @@
         tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/hello/'])
         tree.add('hello', b'hello-id')
-        file_conflict = conflicts.TextConflict('file', b'hello-id')
-        tree.set_conflicts(conflicts.ConflictList([file_conflict]))
-        tree.auto_resolve()
+        file_conflict = conflicts.TextConflict('hello', b'hello-id')
+        tree.set_conflicts(conflicts.ConflictList([file_conflict]))
+        remaining, resolved = self._auto_resolve(tree)
+        self.assertEqual(
+            remaining,
+            conflicts.ConflictList([conflicts.TextConflict(u'hello', 'hello-id')]))
+        self.assertEqual(resolved, [])
+
+    def test_auto_resolve_missing(self):
+        tree = self.make_branch_and_tree('tree')
+        file_conflict = conflicts.TextConflict('hello', b'hello-id')
+        tree.set_conflicts(conflicts.ConflictList([file_conflict]))
+        remaining, resolved = self._auto_resolve(tree)
+        self.assertEqual(remaining, [])
+        self.assertEqual(
+            resolved,
+            conflicts.ConflictList([conflicts.TextConflict(u'hello', 'hello-id')]))
 
 
 class TestStoredUncommitted(TestCaseWithTransport):

=== modified file 'breezy/workingtree.py'
--- breezy/workingtree.py	2019-06-04 00:08:59 +0000
+++ breezy/workingtree.py	2019-06-18 11:21:15 +0000
@@ -31,7 +31,6 @@
 
 import errno
 import os
-import re
 import sys
 
 import breezy
@@ -68,6 +67,7 @@
     )
 from .i18n import gettext
 from . import mutabletree
+from .symbol_versioning import deprecated_method, deprecated_in
 from .trace import mutter, note
 
 
@@ -1233,6 +1233,7 @@
         """
         raise NotImplementedError(self.walkdirs)
 
+    @deprecated_method(deprecated_in((3, 0, 1)))
     def auto_resolve(self):
         """Automatically resolve text conflicts according to contents.
 
@@ -1246,21 +1247,14 @@
         with self.lock_tree_write():
             un_resolved = _mod_conflicts.ConflictList()
             resolved = _mod_conflicts.ConflictList()
-            conflict_re = re.compile(b'^(<{7}|={7}|>{7})')
             for conflict in self.conflicts():
-                path = self.id2path(conflict.file_id)
-                if (conflict.typestring != 'text conflict' or
-                        self.kind(path) != 'file'):
+                try:
+                    conflict.action_auto(self)
+                except NotImplementedError:
                     un_resolved.append(conflict)
-                    continue
-                with open(self.abspath(path), 'rb') as my_file:
-                    for line in my_file:
-                        if conflict_re.search(line):
-                            un_resolved.append(conflict)
-                            break
-                    else:
-                        resolved.append(conflict)
-            resolved.remove_files(self)
+                else:
+                    conflict.cleanup(self)
+                    resolved.append(conflict)
             self.set_conflicts(un_resolved)
             return un_resolved, resolved
 

=== modified file 'byov.conf'
--- byov.conf	2019-06-15 13:39:46 +0000
+++ byov.conf	2019-06-18 11:21:15 +0000
@@ -30,7 +30,7 @@
 # FIXME: Arguably this should be vm.build_deps=brz but it requires either an
 # available package or at least a debian/ dir ? -- vila 2018-02-23
 brz.build_deps = gcc, debhelper, python, python-all-dev, python3-all-dev, python-configobj, python3-configobj, python-docutils, python3-docutils, python-paramiko, python3-paramiko, python-subunit, python3-subunit, python-testtools, python3-testtools, subunit, python-pip, python3-pip, python-setuptools, python3-setuptools, python-flake8, python3-flake8, python-sphinx, python3-sphinx, python-launchpadlib, python3-launchpadlib
-subunit.build_deps = python-testscenarios, python3-testscenarios, python-testtools, python3-testtools, quilt
+subunit.build_deps = python-testscenarios, python3-testscenarios, python-testtools, python3-testtools, cython, cython3, quilt
 vm.packages = {brz.build_deps}, {subunit.build_deps}, bzr, git, python-junitxml
 [brz-xenial]
 vm.release = xenial
@@ -41,12 +41,19 @@
 vm.release = bionic
 [brz-cosmic]
 vm.release = cosmic
+[brz-disco]
+vm.release = disco
+vm.packages = {brz.build_deps}, {subunit.build_deps}, bzr, git, python-dulwich, python3-dulwich, python-junitxml
+byoci.setup.command = ({subunit.clone} && {sphinx_epytext.install} && {sphinx_epytext.install3} )
+byoci.tests.command = bash -o pipefail -c "bzr log -l2 && (PYTHONPATH=../subunit/python:$PYTHONPATH PATH=../subunit/filters:$HOME/.local/bin:$PATH make check-ci | subunit2junitxml -o ../results.xml -f | subunit2pyunit)"
+[brz-eoan]
+vm.release = eoan
 lxd.image = ubuntu-daily:{vm.release}/{vm.architecture}
 [brz-buster]
 vm.distribution = debian
 vm.release = buster
 vm.packages = {brz.build_deps}, {subunit.build_deps}, bzr, git, python-dulwich, python3-dulwich, python-junitxml
-byoci.setup.command = ({subunit.clone})
+byoci.setup.command = ({subunit.clone} && {sphinx_epytext.install} && {sphinx_epytext.install3} )
 byoci.tests.command = bash -o pipefail -c "bzr log -l2 && (PYTHONPATH=../subunit/python:$PYTHONPATH PATH=../subunit/filters:$HOME/.local/bin:$PATH make check-ci | subunit2junitxml -o ../results.xml -f | subunit2pyunit)"
 [brz-sid]
 vm.distribution = debian

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2018-11-18 13:43:04 +0000
+++ doc/developers/releasing.txt	2019-06-18 10:52:09 +0000
@@ -182,7 +182,7 @@
 The process for releasing an alpha release is therefore:
 - upload a tarball to launchpad,
 - upload a tarball to pypi,
-- mail bazaar@lists.canonical.com,
+- mail bazaar@lists.ubuntu.com,
 - post an announcement on the home page.  
 
 Uploading tarballs are described below, just use alpha versions (3, 0, 0,
@@ -485,9 +485,10 @@
 Announcing the source freeze
 ----------------------------
 
-#. Post to the ``bazaar@lists.canonical.com`` list, saying that the source
-   has been frozen. Be extra clear that this is only a *source* release
-   targeted at packagers and installer builders (see
+#. Post to the ``bazaar@lists.ubuntu.com`` list and
+   ``breezy-vcs@googlegroups.com`` , saying that the source has been
+   frozen. Be extra clear that this is only a *source* release targeted at
+   packagers and installer builders (see
    <https://bugs.launchpad.net/launchpad/+bug/645084>).  This is the cue for
    platform maintainers and plugin authors to update their code.  This is
    done before the general public announcement of the release.
@@ -542,14 +543,14 @@
 
 #. Make an announcement mail.
 
-   For beta releases, this is sent to the ``bazaar@lists.canonical.com`` and
-   ``bazaar-announce@lists.canonical.com`` lists.
+   For beta releases, this is sent to the ``bazaar@lists.ubuntu.com`` and
+   ``bazaar-announce@lists.ubuntu.com`` lists.
 
    For stable releases (excluding SRUs which are for older stable releases),
    it should also be cc'd to ``info-gnu@gnu.org``,
    ``python-announce-list@python.org``, ``bug-directory@gnu.org``.
 
-   In all cases, it is good to set ``Reply-To: bazaar@lists.canonical.com``,
+   In all cases, it is good to set ``Reply-To: bazaar@lists.ubuntu.com``,
    so that people who reply to the announcement don't spam other lists.
 
    The announce mail will look something like this::
@@ -622,7 +623,7 @@
    To be able to upload the release you must create an account on
    <http://pypi.python.org/pypi> and have one of the existing owners of the
    project add you to the group and update your ``[pypi]`` section in your
-   ``~/pypirc`` file.
+   ``~/.pypirc`` file.
 
 
 Merging the released code back to trunk

=== modified file 'doc/en/release-notes/brz-3.0.txt'
--- doc/en/release-notes/brz-3.0.txt	2019-06-03 03:10:29 +0000
+++ doc/en/release-notes/brz-3.0.txt	2019-06-18 11:21:15 +0000
@@ -5,11 +5,66 @@
 .. toctree::
    :maxdepth: 1
 
+brz 3.0.2
+#########
+
+:3.0.2: NOT RELEASED YET
+
+External Compatibility Breaks
+*****************************
+
+.. These may require users to change the way they use Breezy.
+
+New Features
+************
+
+.. New commands, options, etc that users may wish to try out.
+
+Improvements
+************
+
+.. Improvements to existing commands, especially improved performance 
+   or memory usage, or better results.
+
+Bug Fixes
+*********
+
+.. Fixes for situations where brz would previously crash or give incorrect
+   or undesirable results.
+
+Documentation
+*************
+
+.. Improved or updated documentation.
+
+API Changes
+***********
+
+.. Changes that may require updates in plugins or other code that uses
+   breezy.
+
+Internals
+*********
+
+.. Major internal changes, unlikely to be visible to users or plugin 
+   developers, but interesting for brz developers.
+
+Testing
+*******
+
+.. Fixes and changes that are only relevant to brz's test framework and 
+   suite.  This can include new facilities for writing tests, fixes to 
+   spurious test failures and changes to the way things should be tested.
+
+
 bzr 3.0.1
 #########
 
-:3.0.1: NOT RELEASED YET
+:3.0.1: 2019-06-16
 
+brz 3.0.1 is the second release of ``Breezy``, a fork of Bazaar. For more
+information, see our release announcement on the Bazaar mailing list and
+README.
 
 External Compatibility Breaks
 *****************************
@@ -35,13 +90,23 @@
 
 * Fix a nasty corner case merging changes into a tree with changed
   symlinks when pushing from bzr into git.
+  (Jelmer Vernooĳ)
 
 * Fix installation on Windows. (Raoul Snyman, #1818947)
 
+* Fix switching between branches while preserving uncommitted changes in git.
+  (Jelmer Vernooĳ, #1820606)
+
 * Return consist errors from ``Branch.get_revid`` and
   ``Repository.get_revid_for_revno`` when the revision
   number is invalid. (Jelmer Vernooĳ, #701953)
 
+* Print full upgrade command to run when complaining about lack of
+  support for tags. (Jelmer Vernooĳ, #163908)
+
+* Refactor auto conflict handling and add a ``--auto`` flag
+  to ``bzr resolve``. (Martin Packman, #688506)
+
 Documentation
 *************
 
@@ -67,6 +132,7 @@
 
 None.
 
+
 brz 3.0.0
 #########
 

